@@ -181,16 +181,16 @@ static const char *output_option_types[] = {
 #define CONSERVE_MEMORY_OPT	361
 #define MULTIFILE_OPT		362
 
-#define LOOP_TYPE		(Clp_MaxDefaultType + 1)
-#define DISPOSAL_TYPE		(Clp_MaxDefaultType + 2)
-#define DIMENSIONS_TYPE		(Clp_MaxDefaultType + 3)
-#define FRAME_SPEC_TYPE		(Clp_MaxDefaultType + 4)
-#define COLOR_TYPE		(Clp_MaxDefaultType + 5)
-#define POSITION_TYPE		(Clp_MaxDefaultType + 6)
-#define RECTANGLE_TYPE		(Clp_MaxDefaultType + 7)
-#define TWO_COLORS_TYPE		(Clp_MaxDefaultType + 8)
-#define COLORMAP_ALG_TYPE	(Clp_MaxDefaultType + 9)
-#define SCALE_FACTOR_TYPE	(Clp_MaxDefaultType + 10)
+#define LOOP_TYPE		(Clp_FirstUserType)
+#define DISPOSAL_TYPE		(Clp_FirstUserType + 1)
+#define DIMENSIONS_TYPE		(Clp_FirstUserType + 2)
+#define FRAME_SPEC_TYPE		(Clp_FirstUserType + 3)
+#define COLOR_TYPE		(Clp_FirstUserType + 4)
+#define POSITION_TYPE		(Clp_FirstUserType + 5)
+#define RECTANGLE_TYPE		(Clp_FirstUserType + 6)
+#define TWO_COLORS_TYPE		(Clp_FirstUserType + 7)
+#define COLORMAP_ALG_TYPE	(Clp_FirstUserType + 8)
+#define SCALE_FACTOR_TYPE	(Clp_FirstUserType + 9)
 
 Clp_Option options[] = {
   
@@ -1149,15 +1149,15 @@ copy_crop(Gt_Crop *oc)
  **/
 
 int
-main(int argc, char **argv)
+main(int argc, char *argv[])
 {
   Clp_Parser *clp =
-    Clp_NewParser(argc, argv, sizeof(options) / sizeof(options[0]), options);
+    Clp_NewParser(argc, (const char * const *)argv, sizeof(options) / sizeof(options[0]), options);
   
   Clp_AddStringListType
     (clp, LOOP_TYPE, Clp_AllowNumbers,
      "infinite", 0, "forever", 0,
-     0);
+     (const char*) 0);
   Clp_AddStringListType
     (clp, DISPOSAL_TYPE, Clp_AllowNumbers,
      "none", GIF_DISPOSAL_NONE,
@@ -1165,13 +1165,13 @@ main(int argc, char **argv)
      "background", GIF_DISPOSAL_BACKGROUND,
      "bg", GIF_DISPOSAL_BACKGROUND,
      "previous", GIF_DISPOSAL_PREVIOUS,
-     0);
+     (const char*) 0);
   Clp_AddStringListType
     (clp, COLORMAP_ALG_TYPE, 0,
      "diversity", COLORMAP_DIVERSITY,
      "blend-diversity", COLORMAP_BLEND_DIVERSITY,
      "median-cut", COLORMAP_MEDIAN_CUT,
-     0);
+     (const char*) 0);
   Clp_AddType(clp, DIMENSIONS_TYPE, 0, parse_dimensions, 0);
   Clp_AddType(clp, POSITION_TYPE, 0, parse_position, 0);
   Clp_AddType(clp, SCALE_FACTOR_TYPE, 0, parse_scale_factor, 0);
