@@ -174,7 +174,7 @@ static struct timeval preparation_time;
 #define BACKGROUND_OPT		310
 #define NEW_WINDOW_OPT		311
 
-#define WINDOW_TYPE		(Clp_MaxDefaultType + 1)
+#define WINDOW_TYPE		(Clp_FirstUserType)
 
 Clp_Option options[] = {
   { "animate", 'a', ANIMATE_OPT, 0, Clp_Negate },
@@ -1211,7 +1211,7 @@ loop(void)
 
 
 int
-main(int argc, char **argv)
+main(int argc, char *argv[])
 {
   Gt_Viewer *viewer = 0;
   int viewer_given = 0;
@@ -1219,13 +1219,13 @@ main(int argc, char **argv)
   int first_frame = -1;
   
   Clp_Parser *clp =
-    Clp_NewParser(argc, argv,
+    Clp_NewParser(argc, (const char * const *)argv,
                   sizeof(options) / sizeof(options[0]), options);
   Clp_SetOptionChar(clp, '+', Clp_ShortNegated);
   Clp_AddStringListType
     (clp, WINDOW_TYPE, Clp_AllowNumbers,
      "root", -1,
-     0);
+     (const char*) 0);
   program_name = cur_resource_name = Clp_ProgramName(clp);
   
   xwGETTIMEOFDAY(&genesis_time);
